class Project():

    def __init__(self, client, project_id=None):
        self.client     = client
        self.project_id = project_id

    def get_details(self, project_id=None):

        """
            Get information about a specific project
            http://developer.dribbble.com/v1/projects/#get-a-project
        """

        project_id      = project_id if project_id is not None else self.project_id
        project_details = self.client.GET("/projects/{}".format(project_id))
        return project_details.json()

    def get_shots(self, project_id=None):

        """
            Retrieves a list of all shots that are part of this project
            http://developer.dribbble.com/v1/projects/shots/#list-shots-for-a-project
        """

        project_id      = project_id if project_id is not None else self.project_id
        shots           = self.client.GET("/projects/{}/shots".format(project_id))
        return shots.json()



import requests as req

__author__ = "Karim Cheurfi"

API_URL         = "https://api.dribbble.com/v1"
AUTH_ENDPOINT   = "https://dribbble.com/oauth/authorize"
OAUTH_ENDPOINT  = "https://dribbble.com/oauth/token"
SCOPE           = ['write', 'public', 'comment', 'upload']

class Jabbbar(object):

    def __init__(self, client_id=None, client_secret=None, redirect_uri=None, access_token=None, state=None, scope=SCOPE):
        self.client_id          = client_id
        self.client_secret      = client_secret
        self.redirect_uri       = redirect_uri
        self.state              = state
        self.scope              = "+".join(scope)
        self.access_token       = access_token
        self.auth_header        = {'Authorization': 'Bearer {}'.format(self.access_token)}

    @property
    def auth_url(self):

        """ Generates a URL to the authorize endpoint used by dribbble to return a grant_code """

        return "{}?client_id={}&redirect_uri={}&scope={}&state={}".format(AUTH_ENDPOINT, self.client_id,\
                self.redirect_uri, self.scope, self.state)

    def set_access_token(self, auth_code=None):

        """ takes the grant code provided during Object.generate_auth_url() and makes a request to the dribbble api for
        an access token. Extracts it from the response and stores it a an instance variable"""

        oauth_params = {
            'client_id': self.client_id,
            'client_secret': self.client_secret,
            'code': auth_code,
            'redirect_uri': self.redirect_uri
        }
        token_request       = req.post(OAUTH_ENDPOINT, data=oauth_params)
        token_response      = token_request.json()
        access_token        = token_response['access_token']
        self.access_token   = access_token

    def _create_request_url(self, resource_url):
        return "{api_endpoint}{resource_url}".format(api_endpoint=API_URL, resource_url=resource_url)

    def GET(self, resource_endpoint):
        url         = self._create_request_url(resource_endpoint)
        return req.get(url, headers=self.auth_header)

    def POST(self, resource_endpoint, data={}):
        url         = self._create_request_url(resource_endpoint)
        return req.post(url, headers=self.auth_header, data=data)

    def PUT(self, resource_endpoint, data={}):
        url         = self._create_request_url(resource_endpoint)
        return req.put(url, headers=self.auth_header, data=data)

    def DELETE(self, resource_endpoint):
        url         = self._create_request_url(resource_endpoint)
        return req.delete(url, headers=self.auth_header)



from jabbbar import Team
from . import client

DEFAULT_TEAM_ID = "Creativedash"
test_team = Team(client, DEFAULT_TEAM_ID)


def test_list_players():
    # List all the players who are part of the instanciated team
    response        = test_team.list_players()
    assert isinstance(response, list)

    # List all the players who are part of another team
    response        = test_team.list_players(team_name="ueno")
    assert isinstance(response, list)


def test_list_shots():
    # List all the shots published by the instanciated team
    response        = test_team.list_shots()
    assert isinstance(response, list)

    # List all the shots published by another team
    response        = test_team.list_shots(team_name="ueno")
    assert isinstance(response, list)



import time
from jabbbar import User
from . import client

DEFAULT_SHOT_ID            = 1757843
DEFAULT_COMMENT_ID         = 3991565
EXTERNAL_SHOT_ID           = 3064133
EXTERNAL_COMMENT_ID        = 5690090
DEFAULT_ATTACHEMENT_ID     = 285772
TEST_USERNAME   = "kolage"
test_user       = User(client)

def test_get_user():
    time.sleep(1.1)
    response = test_user.get_details()
    assert 'username' in response

    time.sleep(1.1)
    response = test_user.get_details(username=TEST_USERNAME)
    assert response['username'] == TEST_USERNAME

def test_list_buckets():
    response = test_user.list_buckets()
    time.sleep(1.1)
    assert isinstance(response, list)

    time.sleep(1.1)
    response = test_user.list_buckets(username=TEST_USERNAME)
    assert isinstance(response, list)

def test_list_projects():
    time.sleep(1.1)
    response = test_user.list_projects()
    assert isinstance(response, list)

    time.sleep(1.1)
    response = test_user.list_projects(username=TEST_USERNAME)
    assert isinstance(response, list)

def test_list_shot_likes():
    time.sleep(1.1)
    response = test_user.list_shot_likes()
    assert isinstance(response, list)

    time.sleep(1.1)
    response = test_user.list_shot_likes(username=TEST_USERNAME)
    assert isinstance(response, list)

def test_list_shots():
    time.sleep(1.1)
    response = test_user.list_shots()
    assert isinstance(response, list)

    time.sleep(1.1)
    response = test_user.list_shots(username=TEST_USERNAME)
    assert isinstance(response, list)

def test_list_teams():
    time.sleep(1.1)
    response = test_user.list_teams()
    assert isinstance(response, list)

    time.sleep(1.1)
    response = test_user.list_teams(username=TEST_USERNAME)
    assert isinstance(response, list)

def test_list_followers():
    time.sleep(1.1)
    response = test_user.list_followers()
    assert isinstance(response, list)

    time.sleep(1.1)
    response = test_user.list_followers(username=TEST_USERNAME)
    assert isinstance(response, list)

def test_list_following():
    time.sleep(1.1)
    response = test_user.list_following()
    assert isinstance(response, list)

    time.sleep(1.1)
    response = test_user.list_following(username=TEST_USERNAME)
    assert isinstance(response, list)

def test_list_following_shots():
    time.sleep(1.1)
    response = test_user.list_shots_from_following()
    assert isinstance(response, list)

def test_check_user_is_following():

    time.sleep(1.1)
    # current user follows target user
    response = test_user.check_following(target_user=TEST_USERNAME)
    status_code = response.__dict__['status_code']
    assert status_code == 204

    time.sleep(1.1)
    # current user does not follow target user
    response = test_user.check_following("RypeArts")
    status_code = response.__dict__['status_code']
    assert status_code == 404

    time.sleep(1.1)
    # user does not follow target user
    response = test_user.check_following(username=TEST_USERNAME, target_user="MilkshakePanda")
    status_code = response.__dict__['status_code']
    assert status_code == 404

    time.sleep(1.1)
    # user follows the target user
    response = test_user.check_following(username=TEST_USERNAME, target_user="ghanipradita")
    status_code = response.__dict__['status_code']
    assert status_code == 204

def test_follow():
    time.sleep(1.1)
    response    = test_user.follow_user(target_user="luisamf")
    status_code = response.__dict__['status_code']
    assert status_code == 204

def test_unfollow():
    # follow ghani then unfollow him
    time.sleep(1.1)
    response    = test_user.follow_user(target_user="ghanipradita")
    status_code = response.__dict__['status_code']
    response    = test_user.unfollow_user(target_user="ghanipradita")
    assert status_code == 204

def test_upload_shot():
    pass

def test_update_shot():
    pass

def test_delete_shot():
    pass

def test_check_user_likes_shot():
    # If the current user likes the shot it should return 200 along with an object
    time.sleep(1.1)
    response            = test_user.check_user_likes_shot(DEFAULT_SHOT_ID)
    status_code         = response.__dict__['status_code']
    assert status_code == 200

    # If the current user does not like
    time.sleep(1.1)
    response            = test_user.check_user_likes_shot(EXTERNAL_SHOT_ID)
    status_code         = response.__dict__['status_code']
    assert status_code == 404

def test_check_user_likes_comment():
    # User Does Not Like The Comment
    time.sleep(1.1)
    response            = test_user.check_user_likes_comment(DEFAULT_COMMENT_ID, DEFAULT_SHOT_ID)
    status_code         = response.__dict__['status_code']
    assert status_code == 404

    # User likes the comment
    time.sleep(1.1)
    response            = test_user.check_user_likes_comment(DEFAULT_COMMENT_ID + 2, DEFAULT_SHOT_ID)
    status_code         = response.__dict__['status_code']
    assert status_code == 200



from jabbbar import Project
from . import client

DEFAULT_PROJECT_ID = 3

test_project = Project(client, DEFAULT_PROJECT_ID)

def test_get_details():
    response = test_project.get_details()
    assert response['id'] == test_project.project_id

    response = test_project.get_details(project_id=4)
    assert response['id'] == 4

def test_get_shots():
    response = test_project.get_shots()
    assert isinstance(response, list)

    response = test_project.get_shots(project_id=4)
    assert isinstance(response, list)



class Shot():

    def __init__(self, client, shot_id=None):
        self.client  = client
        self.shot_id = shot_id

    def list_all(self, params):

        """
            Retrieve a list of all uploaded shots on the site
            http://developer.dribbble.com/v1/shots/#list-shots
        """

        shots = self.client.GET("/shots")
        return shots.json()

    def get_one(self, shot_id=None):

        """
            Get details for a specific shot
            http://developer.dribbble.com/v1/shots/#get-a-shot
        """

        shot_id             = shot_id if shot_id is not None else self.shot_id
        shot_info   = self.client.GET("/shots/{}".format(shot_id))
        return shot_info.json()

    def list_attachments(self, shot_id=None):

        """
            List attachments for a shot
            http://developer.dribbble.com/v1/shots/attachments/#list-attachments-for-a-shot
        """

        shot_id             = shot_id if shot_id is not None else self.shot_id
        attachments         = self.client.GET("/shots/{}/attachments".format(shot_id))
        return attachments.json()

    def get_attachment(self, attachment_id, shot_id=None):

        """
            get a single attachment for shot
            http://developer.dribbble.com/v1/shots/attachments/#get-a-single-attachment
        """
        shot_id             = shot_id if shot_id is not None else self.shot_id
        attachment          = self.client.GET("/shots/{}/attachments/{}".format(shot_id, attachment_id))
        return attachment.json()

    def list_buckets(self, shot_id=None):

        """
            List all buckets a shot is part of
            http://developer.dribbble.com/v1/shots/buckets/
        """

        shot_id             = shot_id if shot_id is not None else self.shot_id
        buckets             = self.client.GET("/shots/{}/buckets".format(shot_id))
        return buckets.json()

    def list_comments(self, shot_id=None):
        """
            List all the comments for a shot
            http://developer.dribbble.com/v1/shots/comments/#list-comments-for-a-shot
        """
        shot_id             = shot_id if shot_id is not None else self.shot_id
        comments            = self.client.GET("/shots/{}/comments".format(shot_id))
        return comments.json()

    def list_comment_likes(self, comment_id, shot_id=None):

        """
            List all likes for a single comment in a single shot
            http://developer.dribbble.com/v1/shots/comments/#list-likes-for-a-comment
        """

        shot_id                 = shot_id if shot_id is not None else self.shot_id
        comment_likes           = self.client.GET("/shots/{}/comments/{}/likes".format(shot_id, comment_id))
        return comment_likes.json()

    def get_comment(self, comment_id, shot_id=None):

        """
            Get a single comment for a single shot
            http://developer.dribbble.com/v1/shots/comments/#get-a-single-comment
        """
        shot_id                 = shot_id if shot_id is not None else self.shot_id
        comment                 = self.client.GET("/shots/{}/comments/{}".format(shot_id, comment_id))
        return comment.json()


    def like_comment(self, comment_id, shot_id=None):


        """
            Add like to a single comment
            http://developer.dribbble.com/v1/shots/comments/#like-a-comment
        """
        shot_id                 = shot_id if shot_id is not None else self.shot_id
        like                    = self.client.POST("/shots/{}/comments/{}/like".format(shot_id, comment_id))
        return like.json()

    def unlike_comment(self, comment_id, shot_id=None):

        """
            Unlikes a previously liked comment
            http://developer.dribbble.com/v1/shots/comments/#unlike-a-comment
        """
        shot_id                 = shot_id if shot_id is not None else self.shot_id
        unlike                  = self.client.DELETE("/shots/{}/comments/{}/like".format(shot_id, comment_id))
        return unlike

    def list_likes(self, shot_id=None):

        """
            List all the likes for a shot
            http://developer.dribbble.com/v1/shots/likes/#list-the-likes-for-a-shot
        """

        shot_id                 = shot_id if shot_id is not None else self.shot_id
        shot_likes              = self.client.GET("/shots/{}/likes".format(shot_id))
        return shot_likes.json()

    def like(self, shot_id=None):

        """
            Like a single shot
            http://developer.dribbble.com/v1/shots/likes/#like-a-shot
        """

        shot_id                 = shot_id if shot_id is not None else self.shot_id
        like                    = self.client.POST("/shots/{}/like".format(shot_id))
        return like.json()

    def unlike(self, shot_id=None):

        """
            Unlike a single shot
            http://developer.dribbble.com/v1/shots/likes/#unlike-a-shot
        """

        shot_id                 = shot_id if shot_id is not None else self.shot_id
        unlike                  = self.client.DELETE("/shots/{}/like".format(shot_id))
        return unlike

    def list_projects(self, shot_id=None):

        """
            List all the projects for a shot
            http://developer.dribbble.com/v1/shots/projects/#list-projects-for-a-shot
        """

        shot_id                 = shot_id if shot_id is not None else self.shot_id
        projects                = self.client.GET("/shots/{}/projects".format(shot_id))
        return projects.json()

    def list_rebounds(self, shot_id=None):

        """
            List all the rebounds for a shot
            http://developer.dribbble.com/v1/shots/rebounds/
        """

        shot_id                 = shot_id if shot_id is not None else self.shot_id
        projects                = self.client.GET("/shots/{}/rebounds".format(shot_id))
        return projects.json()



from jabbbar import Bucket
from . import client
import time

EXTERNAL_BUCKET_ID  = 2755
BUCKET_TO_UPDATE    = 442480
DEFAULT_SHOT_ID     = 471756
DEFAULT_BUCKET_ID   = 386137

test_bucket = Bucket(client, DEFAULT_BUCKET_ID)

def test_get_details():
    # Without ID (the instance bucket)
    time.sleep(1)
    response = test_bucket.get_details()
    assert 'shots_count' in response

    # With ID (another bucket)
    response = test_bucket.get_details(bucket_id=EXTERNAL_BUCKET_ID)
    assert 'shots_count' in response

def test_create_and_delete_bucket():
    time.sleep(1)
    bucket_name, bucket_description = ["my new name", "new cool bucket"]
    response            = test_bucket.create(name=bucket_name, description=bucket_description)
    assert 'created_at' in response

    response = test_bucket.delete(bucket_id=response['id'])
    status_code = response.__dict__['status_code']
    assert status_code == 204

def test_update_bucket():
    # Without ID (the instance bucket)
    time.sleep(1)
    bucket_new_name = "Jobs board for python developers"
    response        = test_bucket.update(name=bucket_new_name)
    assert bucket_new_name == response['name']

    # With ID (another bucket)
    time.sleep(1)
    bucket_new_name = "bruv wagwan"
    response        = test_bucket.update(bucket_id=BUCKET_TO_UPDATE, name=bucket_new_name)
    assert bucket_new_name == response['name']

def test_list_all_shots():
    # Without ID (the instance bucket)
    time.sleep(1)
    response    = test_bucket.list_shots()
    assert isinstance(response, list)

    # With Id (another bucket)
    time.sleep(1)
    response    = test_bucket.list_shots(bucket_id=EXTERNAL_BUCKET_ID)
    assert isinstance(response, list)

def test_add_shot():
    time.sleep(1)
    response    = test_bucket.add_shot(shot_id=DEFAULT_SHOT_ID)
    status_code = response.__dict__['status_code']
    assert status_code == 204

def test_remove_shot():
    time.sleep(1)
    response    = test_bucket.remove_shot(shot_id=DEFAULT_SHOT_ID)
    status_code = response.__dict__['status_code']
    assert status_code == 204



class User():

    def __init__(self, client):
        self.client     = client

    def get_details(self, username=None):

        if username is not None:
            user_details        = self.client.GET("/users/{username}".format(username=username))
        else:
            user_details        = self.client.GET("/user")

        return user_details.json()

    def list_buckets(self, username=None):

        if username is not None:
            buckets             = self.client.GET("/users/{username}/buckets".format(username=username))
        else:
            buckets             = self.client.GET("/user/buckets")

        return buckets.json()

    def list_shot_likes(self, username=None):

        if username is not None:
            shot_likes          = self.client.GET("/users/{username}/likes".format(username=username))
        else:
            shot_likes          = self.client.GET("/user/likes")

        return shot_likes.json()

    def list_projects(self, username=None):

        if username is not None:
            projects            = self.client.GET("/users/{username}/projects".format(username=username))
        else:
            projects            = self.client.GET("/user/projects")

        return projects.json()

    def list_shots(self, username=None):

        if username is not None:
            shots               = self.client.GET("/users/{username}/shots".format(username=username))
        else:
            shots               = self.client.GET("/user/shots")

        return shots.json()

    def list_teams(self, username=None):

        if username is not None:
            teams               = self.client.GET("/users/{username}/teams".format(username=username))
        else:
            teams               = self.client.GET("/user/teams")

        return teams.json()

    def list_followers(self, username=None):

        if username is not None:
            followers               = self.client.GET("/users/{username}/followers".format(username=username))
        else:
            followers               = self.client.GET("/user/followers")

        return followers.json()

    def list_following(self, username=None):

        if username is not None:
            following               = self.client.GET("/users/{username}/following".format(username=username))
        else:
            following               = self.client.GET("/user/following")

        return following.json()

    def list_shots_from_following(self):

        shots_from_following        = self.client.GET("/user/following/shots")
        return shots_from_following.json()

    def check_following(self, username=None, target_user=None):
        if username is not None:
            following_user          = self.client.GET("/users/{username}/following/{target_user}".format(username=username,
                                                                                             target_user=target_user))
        else:
            following_user          = self.client.GET("/user/following/{target_user}".format(target_user=target_user))

        return following_user

    # follow
    def follow_user(self, target_user):
        follow_user_response        = self.client.PUT("/users/{target_user}/follow".format(target_user=target_user))
        return follow_user_response

    # unfollow
    def unfollow_user(self, target_user):
        unfollow_user_response      = self.client.DELETE("/users/{target_user}/follow".format(target_user=target_user))
        return unfollow_user_response

    def upload_shot(self, shot_data):

        """
            Uploads a shot to the user's account (the user must be authenticated with the upload scope,
        he/she also must be a drafted player
            http://developer.dribbble.com/v1/shots/#create-a-shot
        """
        pass

    def update_shot(self, shot_id, shot_data):

        """
            Update information about a shot
            http://developer.dribbble.com/v1/shots/#update-a-shot
        """
        pass

    def delete_shot(self, shot_id):

        """
            Delete a specific shot
            http://developer.dribbble.com/v1/shots/#delete-a-shot
        """
        pass

    def check_user_likes_shot(self, shot_id):

        """
            Checks if the authenticated user likes a single shot
            http://developer.dribbble.com/v1/shots/likes/#check-if-you-like-a-shot
        """
        like_shot               = self.client.GET("/shots/{}/like".format(shot_id))
        return like_shot

    def check_user_likes_comment(self, comment_id, shot_id):
        """
            Check if the authenticated user likes a comment
            http://developer.dribbble.com/v1/shots/comments/#check-if-you-like-a-comment
        """

        result                  = self.client.GET("/shots/{}/comments/{}/like".format(shot_id, comment_id))
        return result



import os
from jabbbar import Jabbbar

if 'CLIENT_ID' in os.environ and 'CLIENT_SECRET' in os.environ and 'ACCESS_TOKEN' in os.environ:
    CLIENT_ID = os.environ['CLIENT_ID']
    CLIENT_SECRET = os.environ['CLIENT_SECRET']
    ACCESS_TOKEN = os.environ['ACCESS_TOKEN']
else:
    try:
        from jabbbar.tests.credentials import *
    except ImportError:
        print("Please create a credendtials.py file in this package, based upon credentials.example.py")

REDIRECT_URI = "http://localhost:3000"

client = Jabbbar(client_id=CLIENT_ID, client_secret=CLIENT_SECRET, access_token=ACCESS_TOKEN, state="myrandomkey",\
                  redirect_uri=REDIRECT_URI)

def test_generate_auth_url():
    auth_url     = client.auth_url
    assert CLIENT_ID in auth_url
    assert REDIRECT_URI in auth_url



class Team():

    def __init__(self, client, team_name=None):
        self.client     = client
        self.team_name  = str(team_name)


    def list_players(self, team_name=None):
        """
            List a team's players
            http://developer.dribbble.com/v1/teams/members/
        """
        team_name               = str(team_name) if team_name is not None else self.team_name
        team_players            = self.client.GET("/teams/{}/members".format(team_name))
        return team_players.json()


    def list_shots(self, team_name=None):
        """ List a team's shots
            http://developer.dribbble.com/v1/teams/shots/
        """
        team_name               = str(team_name) if team_name is not None else self.team_name
        team_shots              = self.client.GET("/teams/{}/shots".format(team_name))
        return team_shots.json()



class Bucket():

    def __init__(self, client, bucket_id=None):
        self.client = client
        self.bucket_id = bucket_id

    def get_details(self, bucket_id=None):

        """ Retrieves information about either the current Bucket (if no bucket_id is passed)
            or the one that matches the passed bucket_id
            http://developer.dribbble.com/v1/buckets/#get-a-bucket
        """
        bucket_id   = bucket_id if bucket_id is not None else self.bucket_id
        bucket_details = self.client.GET('/buckets/{}'.format(bucket_id))
        return bucket_details.json()

    def create(self, name=None, description=None):

        """
            Creates a new bucket
            http://developer.dribbble.com/v1/buckets/#create-a-bucket
        """

        bucket_data     = {'name': name, 'description': description}
        post_bucket     = self.client.POST("/buckets", data=bucket_data)
        return post_bucket.json()

    def update(self, bucket_id=None, name=None, description=None):

        """ Update the current bucket or the one that matches the passed bucket_id
            Please note that the user must own the bucket to update it
            http://developer.dribbble.com/v1/buckets/#update-a-bucket
        """

        bucket_id = bucket_id if bucket_id is not None else self.bucket_id
        bucket_data     = {'name': name, 'description': description}
        update_bucket   = self.client.PUT("/buckets/{}".format(bucket_id), data=bucket_data)
        return update_bucket.json()

    def delete(self, bucket_id=None):

        """ Deletes the current bucket or the one that matches the passed bucket_id
            Please note that the user must own the bucket to delete it
            http://developer.dribbble.com/v1/buckets/#delete-a-bucket
        """
        bucket_id       = bucket_id or self.bucket_id
        delete_response = self.client.DELETE('/buckets/{}'.format(bucket_id))
        return delete_response

    def list_shots(self,bucket_id=None):

        """
            Lists all the shots within a the current (or designated) bucket
            http://developer.dribbble.com/v1/buckets/shots/#list-shots-for-a-bucket
        """

        bucket_id       = bucket_id or self.bucket_id
        shots_list      = self.client.GET("/buckets/{}/shots".format(bucket_id))
        return shots_list.json()

    def add_shot(self, shot_id):

        """Adds a shot to the current bucket, we return the raw response so we can test the status code
           Please note that the current user must own the bucket to add shots to it.
           http://developer.dribbble.com/v1/buckets/shots/#add-a-shot-to-a-bucket
        """

        shot_data                = {'shot_id': shot_id}
        new_shot_response        = self.client.PUT("/buckets/{}/shots".format(self.bucket_id), data=shot_data)
        return new_shot_response

    def remove_shot(self, shot_id):

        """Removes a shot from the current bucket, we return the raw response so we can test the status code
           Please note that the current user must own the bucket to remove shots from it.
           http://developer.dribbble.com/v1/buckets/shots/#remove-a-shot-from-a-bucket
        """

        shot_data                    = {'shot_id': shot_id}
        delete_shot_response         = self.client.DELETE("/buckets/{}/shots".format(self.bucket_id))
        return delete_shot_response



import os
import time
from jabbbar import Shot
from . import client

DEFAULT_SHOT_ID            = 1757843
DEFAULT_COMMENT_ID         = 3991565
EXTERNAL_SHOT_ID           = 3064133
EXTERNAL_COMMENT_ID        = 5690090
DEFAULT_ATTACHEMENT_ID     = 285772
test_shot = Shot(client, shot_id=DEFAULT_SHOT_ID)

DEFAULT_SHOT_ID      = 471756

PATH_TO_IMG          = os.path.dirname(__file__)

DEFAULT_UPLOAD_PARAMS = {
    'title': 'Bruv new shot',
    'image': os.path.join(PATH_TO_IMG, 'sample.png'),
    'description': 'Testing shot uploading on this ting',
    'tags': ['mad ting'],
    'team_id': None,
    'rebound_source_id': None
}

DEFAULT_QUERY_PARAMS = {
    'list': 'debuts',
    'timeframe': 'month',
    'date': '20151121',
    'sort': 'comments'
}

def test_list_all():
    time.sleep(1.1)
    response = test_shot.list_all(DEFAULT_QUERY_PARAMS)
    assert isinstance(response, list)

def test_get_one():
    time.sleep(1.1)
    response = test_shot.get_one(DEFAULT_SHOT_ID)
    assert response['id'] == DEFAULT_SHOT_ID

    time.sleep(1.1)
    response = test_shot.get_one(1209392210321321)
    assert 'Not found.' in response['message']

def test_list_attachments():
    # List attachements for the instanciated shot
    time.sleep(1.1)
    response            = test_shot.list_attachments()
    attachment_object  = response[0]
    assert isinstance(response, list)
    assert 'thumbnail_url' in attachment_object

    # List attachements for an external shot
    time.sleep(1.1)
    response            = test_shot.list_attachments(shot_id=3085980)
    attachment_object  = response[0]
    assert isinstance(response, list)
    assert 'thumbnail_url' in attachment_object

def test_get_attachment():
    # Get attachement for the instanciated shot
    time.sleep(1.1)
    response            = test_shot.get_attachment(DEFAULT_ATTACHEMENT_ID)
    assert 'thumbnail_url' in response

    # Get attachement for an external shot
    time.sleep(1.1)
    response            = test_shot.get_attachment(644444, shot_id=EXTERNAL_SHOT_ID)
    assert 'thumbnail_url' in response

def test_list_buckets():
    # List buckets for the instance shot
    time.sleep(1.1)
    response            = test_shot.list_buckets()
    first_bucket        = response[0]
    assert isinstance(response, list)
    assert 'name' in first_bucket

    # List buckets for an external shot
    time.sleep(1.1)
    response            = test_shot.list_buckets(shot_id=EXTERNAL_SHOT_ID)
    first_bucket        = response[0]
    assert isinstance(response, list)
    assert 'name' in first_bucket

def test_list_comments():
    # List all the comments for the instanciated shot
    time.sleep(1.1)
    response            = test_shot.list_comments()
    first_comment       = response[0]
    assert isinstance(response, list)
    assert 'body' in first_comment

    # List all the comments for an external shot
    time.sleep(1.1)
    response            = test_shot.list_comments(shot_id=EXTERNAL_SHOT_ID)
    first_comment       = response[0]
    assert isinstance(response, list)
    assert 'body' in first_comment

def test_comment_likes():
    # List comment likes for a comment in the instance shot
    time.sleep(1.1)
    response            = test_shot.list_comment_likes(DEFAULT_COMMENT_ID)
    first_comment_like  = response[0]
    assert isinstance(response, list)
    assert 'id' in first_comment_like

    # List comment likes for a comment in an external shot
    time.sleep(1.1)
    response            = test_shot.list_comment_likes(EXTERNAL_COMMENT_ID, shot_id=EXTERNAL_SHOT_ID)
    first_comment_like  = response[0]
    assert isinstance(response, list)
    assert 'id' in first_comment_like

def test_get_comment():
    # Get a comment from within the instance shot
    time.sleep(1.1)
    response            = test_shot.get_comment(DEFAULT_COMMENT_ID)
    assert 'created_at' in response

    # Get a comment from an external shot
    time.sleep(1.1)
    response            = test_shot.get_comment(EXTERNAL_COMMENT_ID, shot_id=EXTERNAL_SHOT_ID)
    assert 'created_at' in response

def test_like_comment():
    # Like a comment in the instance's own shot
    time.sleep(1.1)
    response            = test_shot.like_comment(3991574)
    assert 'created_at' in response

    # Like a comment in an external shot
    time.sleep(1.1)
    response            = test_shot.like_comment(EXTERNAL_COMMENT_ID, shot_id=EXTERNAL_SHOT_ID)
    assert 'created_at' in response

def test_unlike_comment():
    time.sleep(1.1)
    like                = test_shot.like_comment(3991757)
    unlike              = test_shot.unlike_comment(3991757)
    status_code         = unlike.__dict__['status_code']
    assert status_code == 204

def test_list_likes():
    # List all the likes for the instanciated shot
    time.sleep(1.1)
    response            = test_shot.list_likes()
    first_like          = response[0]
    assert isinstance(response, list)
    assert 'id' in first_like

    # List all the likes for an external shot
    time.sleep(1.1)
    response            = test_shot.list_likes(shot_id=EXTERNAL_SHOT_ID)
    first_like          = response[0]
    assert isinstance(response, list)
    assert 'id' in first_like

def test_check_user_likes_shot():
    pass

def test_like_shot():
    # Add like to the instanciated shot
    time.sleep(1.1)
    response            = test_shot.like()
    assert 'created_at' in response

    # Add like to an external shot
    time.sleep(1.1)
    response            = test_shot.like(shot_id=EXTERNAL_SHOT_ID)
    assert 'created_at' in response

def test_unlike_shot():
    time.sleep(1.1)
    like                = test_shot.like(shot_id=EXTERNAL_SHOT_ID)
    unlike              = test_shot.unlike(shot_id=EXTERNAL_SHOT_ID)
    status_code         = unlike.__dict__['status_code']
    assert status_code == 204

def test_list_projects():
    # List projects for the instanciated Shot
    time.sleep(1.1)
    response            = test_shot.list_projects()
    assert isinstance(response, list)

    # List projects for an external shot
    time.sleep(1.1)
    response            = test_shot.list_projects(shot_id=EXTERNAL_SHOT_ID)
    assert isinstance(response, list)

def test_list_rebounds():
    # List rebounds for the instanciated Shot
    time.sleep(1.1)
    response            = test_shot.list_rebounds()
    assert isinstance(response, list)

    # List rebounds for an external shot
    time.sleep(1.1)
    response            = test_shot.list_rebounds(shot_id=EXTERNAL_SHOT_ID)
    assert isinstance(response, list)




from setuptools import setup, find_packages

setup(
    name="jabbbar",
    version="0.1.0",
    description="A python 3 wrapper for the Dribbble API",
    url="https://github.com/zabanaa/jabbbar",
    author="Karim Cheurfi (Zabana)",
    author_email="karim.cheurfi@gmail.com",
    license="WTFPL",
    packages=find_packages(exclude=['tests*']),
    install_requires=['requests'],
    keywords=["dribbble", "api", "http", "wrapper", "jabbbar"],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python'
    ]
)
